SubWhisper
---------

Use command for preload model
```python
from subwhisper import setup

setup()
```

Use command for transcribe audio
```python
from subwhisper import process

process(file='/path/to/file')
```
